"use client";
import { useMemo } from "react";
import classNames from "classnames";
/**
 * An interactive pagination component that parameterizes Bootstrap styling
 * options as props.
 * @param numPages - Total number of pages
 * @param numButtons - Number of buttons of numerical indices to show at once
 * @param pageNum - The currently selected page
 * @param setPageNum - Callback function to set the selected page
 * @param ariaLabel - Aria label of the <nav> element
 * @param alignment - Flexbox justify-content setting on the <ul> element
 * @param size - Size variant of the <ul> element
 */
var Pagination = function (_a) {
    var numPages = _a.numPages, numButtons = _a.numButtons, pageNum = _a.pageNum, setPageNum = _a.setPageNum, ariaLabel = _a.ariaLabel, alignment = _a.alignment, size = _a.size;
    var ulClasses = ["pagination"];
    if (size === "small") {
        ulClasses.push("pagination-sm");
    }
    else if (size === "large") {
        ulClasses.push("pagination-lg");
    }
    if (alignment) {
        ulClasses.push("justify-content-".concat(alignment));
    }
    var lowerBound = pageNum - Math.floor((numButtons - 1) / 2);
    var upperBound = pageNum + Math.ceil((numButtons - 1) / 2);
    if (upperBound > numPages) {
        var diff = upperBound - numPages;
        lowerBound = Math.max(lowerBound - diff, 1);
        upperBound -= diff;
    }
    else if (lowerBound < 1) {
        var diff = 1 - lowerBound;
        lowerBound = 1;
        upperBound = Math.min(numPages, upperBound + diff);
    }
    var buttonIndices = useMemo(function () {
        var indices = [];
        for (var i = lowerBound; i <= upperBound; i++) {
            indices.push(i);
        }
        return indices;
    }, [lowerBound, upperBound]);
    function getFirstArrowButton() {
        if (lowerBound === 1) {
            return null;
        }
        return (<li className="page-item">
        <a className="page-link" href="#" aria-label="First" onClick={function (event) {
                event.preventDefault();
                setPageNum(1);
            }}>
          <span aria-hidden="true">&lt;&lt;</span>
        </a>
      </li>);
    }
    function getPrevArrowButton() {
        if (pageNum === 1) {
            return null;
        }
        return (<li className="page-item">
        <a className="page-link" href="#" aria-label="Previous" onClick={function (event) {
                event.preventDefault();
                setPageNum(pageNum - 1);
            }}>
          <span aria-hidden="true">&lt;</span>
        </a>
      </li>);
    }
    function getNextArrowButton() {
        if (pageNum === numPages) {
            return null;
        }
        return (<li className="page-item">
        <a className="page-link" href="#" aria-label="Next" onClick={function (event) {
                event.preventDefault();
                setPageNum(pageNum + 1);
            }}>
          <span aria-hidden="true">&gt;</span>
        </a>
      </li>);
    }
    function getLastArrowButton() {
        if (upperBound === numPages) {
            return null;
        }
        return (<li className="page-item">
        <a className="page-link" href="#" aria-label="Last" onClick={function (event) {
                event.preventDefault();
                setPageNum(numPages);
            }}>
          <span aria-hidden="true">&gt;&gt;</span>
        </a>
      </li>);
    }
    var indexButtons = buttonIndices.map(function (buttonIndex) { return (<li key={buttonIndex} className={classNames({
            "page-item": true,
            active: pageNum === buttonIndex,
        })} aria-current={pageNum === buttonIndex ? "page" : undefined}>
      <a className="page-link" href="#" onClick={function (event) {
            event.preventDefault();
            setPageNum(buttonIndex);
        }}>
        {buttonIndex}
      </a>
    </li>); });
    return (<nav aria-label={ariaLabel}>
      <ul className={classNames(ulClasses)}>
        {getFirstArrowButton()}
        {getPrevArrowButton()}
        {indexButtons}
        {getNextArrowButton()}
        {getLastArrowButton()}
      </ul>
    </nav>);
};
export default Pagination;
